# This file was auto-generated by Fern from our API Definition.

from .environment import MercoaEnvironment
from .resources import (
    Address,
    ApprovalPolicyId,
    AuthHeaderMalformedError,
    AuthHeaderMissingError,
    BankAccountRequest,
    BankAccountResponse,
    BankAddress,
    BankLookupResponse,
    BankStatus,
    BankType,
    BirthDate,
    CardBrand,
    CardRequest,
    CardResponse,
    CardType,
    CheckRequest,
    CheckResponse,
    ColorSchemeRequest,
    ColorSchemeResponse,
    CommentId,
    CurrencyCode,
    CustomPaymentMethodRequest,
    CustomPaymentMethodResponse,
    CustomPaymentMethodUpdateRequest,
    EmailLogResponse,
    EmailProviderRequest,
    EmailProviderResponse,
    EmailSenderProvider,
    EmailSenderRequest,
    EmailSenderResponse,
    EntityId,
    EntityUserId,
    FullName,
    IndividualGovernmentId,
    InvoiceId,
    Itin,
    OcrResponse,
    OrderDirection,
    OrganizationId,
    OrganizationRequest,
    OrganizationResponse,
    PaymentMethodId,
    PaymentMethodRequest,
    PaymentMethodRequest_BankAccount,
    PaymentMethodRequest_Card,
    PaymentMethodRequest_Check,
    PaymentMethodRequest_Custom,
    PaymentMethodResponse,
    PaymentMethodResponse_BankAccount,
    PaymentMethodResponse_Card,
    PaymentMethodResponse_Check,
    PaymentMethodResponse_Custom,
    PaymentMethodSchemaField,
    PaymentMethodSchemaFieldType,
    PaymentMethodSchemaId,
    PaymentMethodSchemaRequest,
    PaymentMethodSchemaResponse,
    PaymentMethodsRequest,
    PaymentMethodsResponse,
    PaymentMethodType,
    PaymentMethodUpdateRequest,
    PaymentMethodUpdateRequest_Custom,
    PaymentRailMarkup,
    PaymentRailMarkupType,
    PaymentRailRequest,
    PaymentRailResponse,
    PhoneNumber,
    Ssn,
    TransactionId,
    TransactionResponse,
    TransactionResponseExpanded,
    TransactionStatus,
    Unauthorized,
    VendorNetwork,
    bank_lookup,
    commons,
    entity,
    invoice,
    ocr,
    organization,
    payment_method,
    payment_method_schema,
    transaction,
)

__all__ = [
    "Address",
    "ApprovalPolicyId",
    "AuthHeaderMalformedError",
    "AuthHeaderMissingError",
    "BankAccountRequest",
    "BankAccountResponse",
    "BankAddress",
    "BankLookupResponse",
    "BankStatus",
    "BankType",
    "BirthDate",
    "CardBrand",
    "CardRequest",
    "CardResponse",
    "CardType",
    "CheckRequest",
    "CheckResponse",
    "ColorSchemeRequest",
    "ColorSchemeResponse",
    "CommentId",
    "CurrencyCode",
    "CustomPaymentMethodRequest",
    "CustomPaymentMethodResponse",
    "CustomPaymentMethodUpdateRequest",
    "EmailLogResponse",
    "EmailProviderRequest",
    "EmailProviderResponse",
    "EmailSenderProvider",
    "EmailSenderRequest",
    "EmailSenderResponse",
    "EntityId",
    "EntityUserId",
    "FullName",
    "IndividualGovernmentId",
    "InvoiceId",
    "Itin",
    "MercoaEnvironment",
    "OcrResponse",
    "OrderDirection",
    "OrganizationId",
    "OrganizationRequest",
    "OrganizationResponse",
    "PaymentMethodId",
    "PaymentMethodRequest",
    "PaymentMethodRequest_BankAccount",
    "PaymentMethodRequest_Card",
    "PaymentMethodRequest_Check",
    "PaymentMethodRequest_Custom",
    "PaymentMethodResponse",
    "PaymentMethodResponse_BankAccount",
    "PaymentMethodResponse_Card",
    "PaymentMethodResponse_Check",
    "PaymentMethodResponse_Custom",
    "PaymentMethodSchemaField",
    "PaymentMethodSchemaFieldType",
    "PaymentMethodSchemaId",
    "PaymentMethodSchemaRequest",
    "PaymentMethodSchemaResponse",
    "PaymentMethodType",
    "PaymentMethodUpdateRequest",
    "PaymentMethodUpdateRequest_Custom",
    "PaymentMethodsRequest",
    "PaymentMethodsResponse",
    "PaymentRailMarkup",
    "PaymentRailMarkupType",
    "PaymentRailRequest",
    "PaymentRailResponse",
    "PhoneNumber",
    "Ssn",
    "TransactionId",
    "TransactionResponse",
    "TransactionResponseExpanded",
    "TransactionStatus",
    "Unauthorized",
    "VendorNetwork",
    "bank_lookup",
    "commons",
    "entity",
    "invoice",
    "ocr",
    "organization",
    "payment_method",
    "payment_method_schema",
    "transaction",
]



# This file was auto-generated by Fern from our API Definition.

from .approver_action import ApproverAction
from .assigned_approver import AssignedApprover
from .associated_approval_action import AssociatedApprovalAction
from .invoice_approver_response import InvoiceApproverResponse
from .invoice_line_item_request import InvoiceLineItemRequest
from .invoice_line_item_response import InvoiceLineItemResponse
from .invoice_order_by_field import InvoiceOrderByField
from .invoice_request import InvoiceRequest
from .invoice_response import InvoiceResponse
from .invoice_status import InvoiceStatus

__all__ = [
    "ApproverAction",
    "AssignedApprover",
    "AssociatedApprovalAction",
    "InvoiceApproverResponse",
    "InvoiceLineItemRequest",
    "InvoiceLineItemResponse",
    "InvoiceOrderByField",
    "InvoiceRequest",
    "InvoiceResponse",
    "InvoiceStatus",
]



# This file was auto-generated by Fern from our API Definition.

from . import approval, comment, document
from .approval import ApprovalRequest
from .comment import CommentRequest, CommentResponse
from .document import DocumentResponse

__all__ = [
    "ApprovalRequest",
    "CommentRequest",
    "CommentResponse",
    "DocumentResponse",
    "approval",
    "comment",
    "document",
]



# This file was auto-generated by Fern from our API Definition.

from .resources import ApprovalRequest, CommentRequest, CommentResponse, DocumentResponse, approval, comment, document
from .types import (
    ApproverAction,
    AssignedApprover,
    AssociatedApprovalAction,
    InvoiceApproverResponse,
    InvoiceLineItemRequest,
    InvoiceLineItemResponse,
    InvoiceOrderByField,
    InvoiceRequest,
    InvoiceResponse,
    InvoiceStatus,
)

__all__ = [
    "ApprovalRequest",
    "ApproverAction",
    "AssignedApprover",
    "AssociatedApprovalAction",
    "CommentRequest",
    "CommentResponse",
    "DocumentResponse",
    "InvoiceApproverResponse",
    "InvoiceLineItemRequest",
    "InvoiceLineItemResponse",
    "InvoiceOrderByField",
    "InvoiceRequest",
    "InvoiceResponse",
    "InvoiceStatus",
    "approval",
    "comment",
    "document",
]



# This file was auto-generated by Fern from our API Definition.

from .amount_trigger import AmountTrigger
from .approval_policy_request import ApprovalPolicyRequest
from .approval_policy_response import ApprovalPolicyResponse
from .approval_policy_update_request import ApprovalPolicyUpdateRequest
from .approver_rule import ApproverRule
from .identifier_list import IdentifierList, IdentifierList_RolesList, IdentifierList_UserList
from .rule import Rule, Rule_Approver
from .trigger import Trigger, Trigger_All, Trigger_Amount

__all__ = [
    "AmountTrigger",
    "ApprovalPolicyRequest",
    "ApprovalPolicyResponse",
    "ApprovalPolicyUpdateRequest",
    "ApproverRule",
    "IdentifierList",
    "IdentifierList_RolesList",
    "IdentifierList_UserList",
    "Rule",
    "Rule_Approver",
    "Trigger",
    "Trigger_All",
    "Trigger_Amount",
]



# This file was auto-generated by Fern from our API Definition.

from .comment_request import CommentRequest
from .comment_response import CommentResponse

__all__ = ["CommentRequest", "CommentResponse"]



# This file was auto-generated by Fern from our API Definition.

from . import approval_policy, counterparty, invoice, payment_method, representative, user
from .approval_policy import (
    AmountTrigger,
    ApprovalPolicyRequest,
    ApprovalPolicyResponse,
    ApprovalPolicyUpdateRequest,
    ApproverRule,
    IdentifierList,
    IdentifierList_RolesList,
    IdentifierList_UserList,
    NumApproverLessThanOneError,
    NumApproversUserListMismatchError,
    Rule,
    Rule_Approver,
    Trigger,
    Trigger_All,
    Trigger_Amount,
)
from .counterparty import CounterpartyResponse, FindCounterpartiesResponse
from .invoice import InvoiceMetricsResponse
from .representative import RepresentativeId, RepresentativeRequest, RepresentativeResponse, Responsibilities
from .user import EntityUserRequest, EntityUserResponse

__all__ = [
    "AmountTrigger",
    "ApprovalPolicyRequest",
    "ApprovalPolicyResponse",
    "ApprovalPolicyUpdateRequest",
    "ApproverRule",
    "CounterpartyResponse",
    "EntityUserRequest",
    "EntityUserResponse",
    "FindCounterpartiesResponse",
    "IdentifierList",
    "IdentifierList_RolesList",
    "IdentifierList_UserList",
    "InvoiceMetricsResponse",
    "NumApproverLessThanOneError",
    "NumApproversUserListMismatchError",
    "RepresentativeId",
    "RepresentativeRequest",
    "RepresentativeResponse",
    "Responsibilities",
    "Rule",
    "Rule_Approver",
    "Trigger",
    "Trigger_All",
    "Trigger_Amount",
    "approval_policy",
    "counterparty",
    "invoice",
    "payment_method",
    "representative",
    "user",
]



# This file was auto-generated by Fern from our API Definition.

from .address import Address
from .approval_policy_id import ApprovalPolicyId
from .birth_date import BirthDate
from .comment_id import CommentId
from .entity_id import EntityId
from .entity_user_id import EntityUserId
from .full_name import FullName
from .individual_government_id import IndividualGovernmentId
from .invoice_id import InvoiceId
from .itin import Itin
from .order_direction import OrderDirection
from .payment_method_id import PaymentMethodId
from .payment_method_schema_id import PaymentMethodSchemaId
from .phone_number import PhoneNumber
from .ssn import Ssn

__all__ = [
    "Address",
    "ApprovalPolicyId",
    "BirthDate",
    "CommentId",
    "EntityId",
    "EntityUserId",
    "FullName",
    "IndividualGovernmentId",
    "InvoiceId",
    "Itin",
    "OrderDirection",
    "PaymentMethodId",
    "PaymentMethodSchemaId",
    "PhoneNumber",
    "Ssn",
]



# This file was auto-generated by Fern from our API Definition.

from .errors import AuthHeaderMalformedError, AuthHeaderMissingError, Unauthorized
from .types import (
    Address,
    ApprovalPolicyId,
    BirthDate,
    CommentId,
    EntityId,
    EntityUserId,
    FullName,
    IndividualGovernmentId,
    InvoiceId,
    Itin,
    OrderDirection,
    PaymentMethodId,
    PaymentMethodSchemaId,
    PhoneNumber,
    Ssn,
)

__all__ = [
    "Address",
    "ApprovalPolicyId",
    "AuthHeaderMalformedError",
    "AuthHeaderMissingError",
    "BirthDate",
    "CommentId",
    "EntityId",
    "EntityUserId",
    "FullName",
    "IndividualGovernmentId",
    "InvoiceId",
    "Itin",
    "OrderDirection",
    "PaymentMethodId",
    "PaymentMethodSchemaId",
    "PhoneNumber",
    "Ssn",
    "Unauthorized",
]



# This file was auto-generated by Fern from our API Definition.

from .errors import NumApproverLessThanOneError, NumApproversUserListMismatchError
from .types import (
    AmountTrigger,
    ApprovalPolicyRequest,
    ApprovalPolicyResponse,
    ApprovalPolicyUpdateRequest,
    ApproverRule,
    IdentifierList,
    IdentifierList_RolesList,
    IdentifierList_UserList,
    Rule,
    Rule_Approver,
    Trigger,
    Trigger_All,
    Trigger_Amount,
)

__all__ = [
    "AmountTrigger",
    "ApprovalPolicyRequest",
    "ApprovalPolicyResponse",
    "ApprovalPolicyUpdateRequest",
    "ApproverRule",
    "IdentifierList",
    "IdentifierList_RolesList",
    "IdentifierList_UserList",
    "NumApproverLessThanOneError",
    "NumApproversUserListMismatchError",
    "Rule",
    "Rule_Approver",
    "Trigger",
    "Trigger_All",
    "Trigger_Amount",
]



# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic

from ......core.datetime_utils import serialize_datetime
from .....entity.resources.user.types.entity_user_response import EntityUserResponse
from ....types.associated_approval_action import AssociatedApprovalAction


class CommentResponse(pydantic.BaseModel):
    id: str
    text: str
    user: typing.Optional[EntityUserResponse]
    associated_approval_action: typing.Optional[AssociatedApprovalAction] = pydantic.Field(
        alias="associatedApprovalAction",
        description=(
            "If an approval action has triggered the generation of this comment, returns the associated approval action and actor\n"
        ),
    )
    created_at: dt.datetime = pydantic.Field(alias="createdAt")
    updated_at: dt.datetime = pydantic.Field(alias="updatedAt")

    def json(self, **kwargs: typing.Any) -> str:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().json(**kwargs_with_defaults)

    def dict(self, **kwargs: typing.Any) -> typing.Dict[str, typing.Any]:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().dict(**kwargs_with_defaults)

    class Config:
        frozen = True
        allow_population_by_field_name = True
        json_encoders = {dt.datetime: serialize_datetime}
